@@ -2,10 +2,15 @@ DELETE IGNORE FROM mysql.plugin WHERE dl = 'ha_mroonga.so';
 
 INSTALL PLUGIN Mroonga SONAME 'ha_mroonga.so';
 
+-- Deprecated. Use mroonga_last_insert_grn_id instead.
 DROP FUNCTION IF EXISTS last_insert_grn_id;
 CREATE FUNCTION last_insert_grn_id RETURNS INTEGER
   SONAME 'ha_mroonga.so';
 
+DROP FUNCTION IF EXISTS mroonga_last_insert_grn_id;
+CREATE FUNCTION mroonga_last_insert_grn_id RETURNS INTEGER
+  SONAME 'ha_mroonga.so';
+
 DROP FUNCTION IF EXISTS mroonga_snippet;
 CREATE FUNCTION mroonga_snippet RETURNS STRING
   SONAME 'ha_mroonga.so';
@@ -29,3 +34,7 @@ CREATE FUNCTION mroonga_normalize RETURNS STRING
 DROP FUNCTION IF EXISTS mroonga_highlight_html;
 CREATE FUNCTION mroonga_highlight_html RETURNS STRING
   SONAME 'ha_mroonga.so';
+
+DROP FUNCTION IF EXISTS mroonga_query_expand;
+CREATE FUNCTION mroonga_query_expand RETURNS STRING
+  SONAME 'ha_mroonga.so';
