@@ -407,8 +407,30 @@ typedef uint mrn_alter_table_flags;
 #  define MRN_HAVE_PSI_SERVER
 #endif
 
+#ifdef MRN_MARIADB_P
+#  if MYSQL_VERSION_ID >= 100302
+  typedef const uchar * mrn_key_copy_from_record_t;
+#  else
+  typedef uchar * mrn_key_copy_from_record_t;
+#  endif
+#else
+#  if MYSQL_VERSION_ID >= 80000
+  using mrn_key_copy_from_record_t = const uchar *;
+#  else
+  typedef uchar * mrn_key_copy_from_record_t;
+#  endif
+#endif
+
 #if MYSQL_VERSION_ID >= 100302 && defined(MRN_MARIADB_P)
-#  define MRN_HANDLER_HA_UPDATE_ROW_NEW_DATA_CONST
+  typedef const uchar * mrn_update_row_new_data_t;
+#else
+  typedef uchar * mrn_update_row_new_data_t;
+#endif
+
+#if MYSQL_VERSION_ID >= 100400 && defined(MRN_MARIADB_P)
+  using mrn_write_row_buf_t = const uchar *;
+#else
+  typedef uchar * mrn_write_row_buf_t;
 #endif
 
 #if MYSQL_VERSION_ID >= 50723 && !defined(MRN_MARIADB_P)
@@ -641,9 +663,9 @@ public:
                    const dd::Table *table_def
 #endif
     ) mrn_override;
-  int write_row(uchar *buf);
-  int update_row(const uchar *old_data, const uchar *new_data);
-  int update_row(const uchar *old_data, uchar *new_data);
+  int write_row(mrn_write_row_buf_t buf) mrn_override;
+  int update_row(const uchar *old_data,
+                 mrn_update_row_new_data_t new_data) mrn_override;
   int delete_row(const uchar *buf);
 
   uint max_supported_record_length()   const;
@@ -1258,14 +1280,15 @@ private:
 #endif
   bool wrapper_is_target_index(KEY *key_info);
   bool wrapper_have_target_index();
-  int wrapper_write_row(uchar *buf);
-  int wrapper_write_row_index(uchar *buf);
-  int storage_write_row(uchar *buf);
-  int storage_write_row_multiple_column_index(uchar *buf,
+  int wrapper_write_row(mrn_write_row_buf_t buf);
+  int wrapper_write_row_index(mrn_write_row_buf_t buf);
+  int storage_write_row(mrn_write_row_buf_t buf);
+  int storage_write_row_multiple_column_index(mrn_write_row_buf_t buf,
                                               grn_id record_id,
                                               KEY *key_info,
                                               grn_obj *index_column);
-  int storage_write_row_multiple_column_indexes(uchar *buf, grn_id record_id);
+  int storage_write_row_multiple_column_indexes(mrn_write_row_buf_t buf,
+                                                grn_id record_id);
   int storage_write_row_unique_index(const uchar *buf,
                                      KEY *key_info,
                                      grn_obj *index_table,
@@ -1273,11 +1296,15 @@ private:
                                      grn_id *key_id);
   int storage_write_row_unique_indexes(const uchar *buf);
   int wrapper_get_record_id(uchar *data, grn_id *record_id, const char *context);
-  int wrapper_update_row(const uchar *old_data, const uchar *new_data);
-  int wrapper_update_row_index(const uchar *old_data, const uchar *new_data);
-  int storage_update_row(const uchar *old_data, const uchar *new_data);
-  int storage_update_row_index(const uchar *old_data, const uchar *new_data);
-  int storage_update_row_unique_indexes(const uchar *new_data);
+  int wrapper_update_row(const uchar *old_data,
+                         mrn_update_row_new_data_t new_data);
+  int wrapper_update_row_index(const uchar *old_data,
+                               mrn_update_row_new_data_t new_data);
+  int storage_update_row(const uchar *old_data,
+                         mrn_update_row_new_data_t new_data);
+  int storage_update_row_index(const uchar *old_data,
+                               mrn_update_row_new_data_t new_data);
+  int storage_update_row_unique_indexes(mrn_update_row_new_data_t new_data);
   int wrapper_delete_row(const uchar *buf);
   int wrapper_delete_row_index(const uchar *buf);
   int storage_delete_row(const uchar *buf);
